.\"
.\" Copyright (c) 1994 1995 1996 ... 2024 2025
.\"     John McCue
.\"
.\" Permission to use, copy, modify, and distribute this software
.\" for any purpose with or without fee is hereby granted,
.\" provided that the above copyright notice and this permission
.\" notice appear in all copies.
.\"
.\" THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL
.\" WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED
.\" WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL
.\" THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR
.\" CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
.\" FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
.\" CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
.\" OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
.\" SOFTWARE.
.\"
.TH J2_BYE_LAST 3 "2018-03-07" "JMC" "Local Library Function"
.SH NAME
j2_bye_last() - Bye Last character
.SH SYNOPSIS
.nf
#include <sys/types.h>
#include <j_lib2.h>

long int j2_bye_last(char *s, char lastc);
long int j2_bye_nl(char *s);
long int j2_bye_ctlm(char *s);
.fi
.SH DESCRIPTION
.BR j2_bye_last()
Removes character 'lastc' from the string if
that character is the last character on the string.
The last character is replaced by a NULL.

.BR j2_bye_nl()
Is equivalent to j2_bye_last(s, '\\n');

.BR j2_bye_ctlm()
Is equivalent to j2_bye_last(s, '\\r');
.SH EXAMPLE
Removes the new-line character from the end of the string
if it is there.
.nf

{
  char s[12];
  long int str_size;

  str_size = j2_bye_last(s, '\\n');
}
.fi
.SH DIAGNOSTICS
If processing DOS Files and you want
to remove 'DOS type new line', do:
.nf
    j2_bye_nl(s);
    j2_bye_ctlm(s);
.fi
but, if you are planning on using
j2_rtw(3), no need to call
j2_bye_nl(3) and j2_bye_ctlm(3)
since j2_rtw(3) will remove
all trailing white space.
.PP
Will remove just the one character at the end of the string.
.PP
End of the string occurs at the first NULL character.
.SH RETURNS
Size of the String after removing the 'last' character
.SH SEE-ALSO
j_lib2(3)
