/*
 * Copyright (c) 2023 2024 2025
 *     John McCue
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#ifndef _MSDOS
#include <sys/param.h>
#endif

#include <stdio.h>
#include <string.h>
#include "j_lib2.h"

/*
 * j2_d_fmtdt() - format current date/time for status print
 */
char *j2_d_fmtdt(char *datetime, size_t len)
{
  struct s_j2_datetime d;

  if (len < 9)
    return((char *) NULL);
  if (datetime == (char *) NULL)
    return((char *) NULL);

  memset(datetime, 0, len);

  j2_today(&d);

  if (len > 23)
    {
      snprintf(datetime, len, "%04d-%02d-%02d %02d:%02d:%02d.%03d",
	       d.yyyy, d.month, d.dd, d.hh, d.minutes, d.ss, d.mil);
      return(datetime);
    }
  if (len > 12)
    {
      snprintf(datetime, len, "%02d:%02d:%02d.%03d",
	       d.hh, d.minutes, d.ss, d.mil);
      return(datetime);
    }
  if (len > 6)
    {
      snprintf(datetime, len, "%02d.%03d", d.ss, d.mil);
      return(datetime);
    }

  return((char *) NULL);

} /* j2_d_fmtdt() */
