.\"
.\" Copyright (c) 2023 2024 2025
.\"     John McCue
.\"
.\" Permission to use, copy, modify, and distribute this software
.\" for any purpose with or without fee is hereby granted,
.\" provided that the above copyright notice and this permission
.\" notice appear in all copies.
.\"
.\" THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL
.\" WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED
.\" WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL
.\" THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR
.\" CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
.\" FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
.\" CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
.\" OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
.\" SOFTWARE.
.\"
.TH J2_D_FMTDT 3 "2023-09-23" "JMC" "Local Library Function"
.SH NAME
j2_d_fmtdt() - format a date/time string for print
.SH SYNOPSIS
.nf
#include <stdio.h>
#include <string.h>
#include <j_lib2.h>

char *j2_d_fmtdt(char *datetime, size_t len);
.fi
.SH DESCRIPTION
j2_d_fmtdt() - Formats the Current Date/Time
for print.
Can be used to print run statuses.
.nf

Parameters:
    datetime - Resulting formatted date/time string.
    len      - Size allocated to datetime by calling process.
               This value determines what is returned:
                   len   datetime format sent back
                   ----  -------------------------
                   > 23  YYYY-MM-DD hh:mm:ss.lll
                   > 12  hh:mm:ss.lll
                   > 6   ss.lll

               Where:
                   YYYY = Year
                   MM   = Month
                   DD   = Day of Month
                   hh   = Hour
                   mm   = Minutes
                   ss   = Seconds
                   lll  = milliseconds
.fi
.SH RETURNS
Returns a pointer to string datetime or
NULL on error.
.SH EXAMPLE
Print the date
.nf

{
  char datetime[24];

  if (j2_d_fmtdt(datetime, 24) != (char *) NULL)
      printf("%s: status of where we are\\n", datetime);
  else
      printf("Could not generate the time stamp\\n");
}

.fi
.SH SEE-ALSO
ftime(3),
j2_today(3),
gettimeofday(2),
j_lib2(3),
localtime(3)
