.\"
.\" Copyright (c) 1994 1995 1996 ... 2024 2025
.\"     John McCue
.\"
.\" Permission to use, copy, modify, and distribute this software
.\" for any purpose with or without fee is hereby granted,
.\" provided that the above copyright notice and this permission
.\" notice appear in all copies.
.\"
.\" THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL
.\" WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED
.\" WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL
.\" THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR
.\" CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
.\" FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
.\" CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
.\" OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
.\" SOFTWARE.
.\"
.TH J2_DATE_IS_VALID 3 "2018-07-02" "JMC" "Local Library Function"
.SH NAME
.nf
j2_date_is_valid() - Is the Date Structure Valid
j2_dl_valid()      - Is the Date Integer Valid
.fi
.SH SYNOPSIS
#include <j_lib2.h>
.nf

int j2_date_is_valid(s_j2_datetime *d)
int j2_dl_valid(long *d)
.fi
.SH DESCRIPTION
j2_date_is_valid() - Determines if the date portion of
data item s_j2_datetime contains a valid date.
s_j2_datetime is a typedef structure containing the following elements:
.nf
    int month   - Month of the year 1 through 12
    int dd      - Day of the month, 1 through 31, based upon month
    int yy      - Two digit year, 00 through 99
    int yyyy    - four digit year, 0000 through 9999
    int hh      - Hour of the day, 00 through 23
    int minutes - minute of the hour, 00 through 59
    int ss      - second of the minute, 00 through 59
    int mil     - milli-second, 0 through 999
.fi
j2_dl_valid() - Determines if a long int date is valid.
.SH EXAMPLE
Is 19990809 a valid date ?
.nf

{
  s_j2_datetime d;
  long int dl;

  j2_d_init(&d); /* initialize */
  d.yyyy = 1999;
  d.yy   = 99;
  d.month = 9;
  d.dd = 8;

  if (j2_date_is_valid(&d))
    printf("Date valid\\n");
  else
    printf("date NOT valid\\n");

  dl = 19990908L;
  if (j2_dl_valid(dl))
    printf("Date %ld valid\\n", dl);
  else
    printf("date %ld NOT valid\\n", dl);

  dl = 19991308L;
  if (j2_dl_valid(dl))
    printf("Date %ld valid\\n", dl);
  else
    printf("date %ld NOT valid\\n", dl);
}

.fi
.SH RETURN VALUES
TRUE of FALSE

.SH DIAGNOSTICS
Data element yy is checked to make sure it corresponds
to data element yyyy
