.\"
.\" Copyright (c) 1994 1995 1996 ... 2024 2025
.\"     John McCue
.\"
.\" Permission to use, copy, modify, and distribute this software
.\" for any purpose with or without fee is hereby granted,
.\" provided that the above copyright notice and this permission
.\" notice appear in all copies.
.\"
.\" THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL
.\" WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED
.\" WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL
.\" THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR
.\" CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
.\" FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
.\" CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
.\" OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
.\" SOFTWARE.
.\"
.TH J2_GETLINE 3 "2021-12-28" "JMC" "Local Library Function"
.SH NAME
j2_getline() - getline(3) front-end
.SH SYNOPSIS
.nf
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <j_lib2.h>

SSIZE_T j2_getline(char **buf, size_t *n, FILE *fp);
.fi
.SH DESCRIPTION
j2_getline() is a front-end to getline(3).
It allows programs for Operating Systems without getline(3)
to read data without you having to use #ifdefs for getline(3).
If the OS has getline(3), that will be called.
.PP
On the first call, 'buf' must be NULL and n must be set to '0'.
.PP
If your OS has getline(3), see its manual for how to use.
.SH EXAMPLE
.nf
#include <stdio.h>
#include <j_lib2.h>

int main(void)

{
  char *buf = (char) NULL;
  size_t n  = 0;
  FILE *fp;

  fp = fopen("file.txt","r");

  if (fp == (FILE *) NULL)
    fprintf(stderr,"cannot open file\\n");
  else
    {
      while (j2_getline(&buf, &n, fp) > -1)
        fprintf(stdout, "%s", buf);
      fclose(fp);
      if (buf != (char *) NULL)
        {
          free(buf);
          n = 0;
        }
    }
}
.fi

.SH RETURN VALUES
If = -1, EOF or an error occurred, otherwise number
of bytes read.
.SH DIAGNOSTICS
Before the first call to j2_getline() the buffer
must be initialised to NULL and number of bytes
set to 0.
.SH BUGS
Important, for Operating Systems without getline(3),
buffer will be assigned a fixed length and will never
increase in size.
See the definition for SIZE_GETLINE_BUF in include j_lib2.h
for the maximum size of the buffer.
.PP
At some point I will change this restriction.
.SH SEE_ALSO
fgets(3), getline(3),
