.\"
.\" Copyright (c) 1994 ... 2024 2025
.\"     John McCue
.\"
.\" Permission to use, copy, modify, and distribute this software
.\" for any purpose with or without fee is hereby granted,
.\" provided that the above copyright notice and this permission
.\" notice appear in all copies.
.\"
.\" THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL
.\" WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED
.\" WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL
.\" THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR
.\" CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
.\" FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
.\" CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
.\" OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
.\" SOFTWARE.
.\"
.TH J2_TODAY 3 "2018-03-07" "JMC" "Local Library Function"
.SH NAME
j2_today() - Get today's date and time
.SH SYNOPSIS
.nf
#include <sys/types.h>
#include <j_lib2.h>

void j2_today(struct s_j2_datetime *dt);
.fi
.SH DESCRIPTION
j2_today() - loads structure s_j2_datetime with
todays date and time.
.SH EXAMPLE
Get todays date and print it out:
.nf

{
  struct s_j2_datetime d;

  j2_today(&d);

  printf("date/time %02d/%02d/%04d %02d:%02d:%02d.%03d\\n",
          d.month, d.dd, d.yyyy, d.hh, d.minutes, d.ss, d.mil);
}
.fi
.PP
This is the format of structure s_j2_datetime:
.nf
    struct s_j2_datetime
    {
      int month;    /* Month,           01 --12             */
      int dd;       /* Day of Month,    01 -- [28|29|30|31] */
      int yy;       /* two digit year,  00 -- 99            */
      int yyyy;     /* four digit year, 0000 -- 9999        */
      int hh;       /* Hour of the day, 00 -- 23            */
      int minutes;  /* minutes,         00 -- 59            */
      int ss;       /* seconds,         00 -- 59            */
      int mil;      /* milliseconds,    000 -- 999          */
      int tm_isdst; /* Daylight ?  0 = no, > 0 = yes        */
    } ;
.fi
.SH DIAGNOSTICS
This is useful to avoid differences between
various Operating Systems.
.PP
In most cases you may want to use the
native OS functions.
.PP
Unlike UN*X standard, the first month is 1
instead of 0.
.SH RETURNS
nothing
.SH SEE-ALSO
ftime(3),
gettimeofday(2),
j_lib2(3),
localtime(3)
